function flines(clines,epsy,ang0)
%
% fline(clines,epsy,ang0)
%
% cline   2d array with individual contour lines
% epsy    accuracy to detect lines along connection line
% ang0    angle (radians) of connection line
%
% script to decompose individual lines in vector CS
% and to plot them
% take care of lines at connecting line
%
x = [];
y = [];
csize = size(clines);
nmax  = csize(1,2);
count = 1;
cosa = cos(ang0);
sina = sin(ang0);
%
while count < nmax
  nl = clines(2,count);
  x = clines(1,count+1:count+nl);
  y = clines(2,count+1:count+nl);
  count = count + nl + 1;
%
% remove pieces along connection axis in 3 steps
% step 1: remove mid point in a series of at least 3
% step 2: check step 1 for begin and end point
% step 3: split contour if 2 points lie on the connection axis
%
  xt =  x*cosa + y*sina;
  yt = -x*sina + y*cosa;
  izero = find(abs(yt)<epsy);
  nzero = length(izero);
%  
  if(nzero > 2)
     for ii=2:nzero-1
        if ((izero(ii+1)-izero(ii-1)) ==2)
           yt(izero(ii)) = NaN;
        end
     end
%
% check connection including end pieces
%
     izero = find(abs(yt)<epsy);
     nzero = length(izero);
     if(izero(nzero)==nl & izero(1)==1 & izero(nzero-1)==nl-1)
        yt(izero(nzero)) = NaN;
     end
%
% check remaining pieces of 2 succeeding pieces
% if such a piece occurs, add an extra dummy point 
% to the line
  izero = find(abs(yt)<epsy);
  nzero = length(izero);
%
if nzero > 1
    for ii=2,nzero;
        if((izero(ii)-izero(ii-1))==1)
           xx = [xt(1:izero(ii-1)) NaN xt(izero(ii):nl)];
           yy = [yt(1:izero(ii-1)) NaN yt(izero(ii):nl)];
           xt = xx;
           yt = yy;
        end           
     end
  end
end 
%
% backward rotation
%
x = xt*cosa - yt*sina;
y = xt*sina + yt*cosa;
%
line(x,y,'color','k');
x = [];
y = [];
end
 
