function zz=write_swan_sp2(S,options)
%
% write swan sp2 spectrum to file 
% Gerbrant van Vledder
% September 2015
%
% set defaults
%
fspec    = 'dummy.sp2';    % dummy file name
iproj    = 0;              % switch to write comment line on project
ktime    = 0;              % switch to write time dependent data
ntime    = 1;              % at least one set of spectra is written
nquant   = 1;              % number of quantities
quant{1} = 'VaDens';       % type of spectrum
unit{1}  = 'm2/Hz/degr';   % unit of spectral data
exc      = -99;            % exception value
coortype = 'LONLAT';       % type of locations
frtype   = 'AFREQ';        % absolute frequencies
dirtype  = 'NDIR';         % Nautical convention 
format   = '%9i';          % Output format of spectrum
%
if nargin==1
  options.fspec = fspec;
end
%
if isfield(options,'fspec')==1; fspec=options.fspec ;end;
if isfield(options,'project')==1; project = options.project;iproj=1;end
if isfield(S,'coortype')==1; coortype = S.coortype;end
if isfield(S,'quant')==1; quant=S.quant;end    
if isfield(S,'unit')==1; unit=S.unit;end
if isfield(S,'exc')==1; exc=S.exc;end
if isfield(S,'frtype')==1;frtype=S.frtype';end
if isfield(S,'dirtype')==1;dirtype=S.dirtype;end
%
% check whether data is time dependent
%
if isfield(S,'t')==1; ktime=1; ntime=length(S.t); end
%
% check extension of fspec
%
idot = strfind(fspec,'.');
if isempty(idot)
  fspec = [fspec '.sp2'];
end
%
% open new file
%
fid = fopen(fspec,'w');
fprintf(fid,'%s\n','SWAN 1     SWAN standard spectra file, version');
fprintf(fid,'%s\n','$  File written by script write_swan_sp2, version 1');
if iproj==1
  fprintf(fid,'%s\n',['$  Project: ' project]);
end
%
% switch to write time header
%
if ktime==1
  fprintf(fid,'%s\n',['TIME          time-dependent data']);    
  fprintf(fid,'%s\n',['      1       time coding options']);    
end    
% 
% location data
%
fprintf(fid,'%s\n',coortype);
nloc = length(S.xloc);
fprintf(fid,'%6i\n',nloc);
for iloc=1:nloc
  fprintf(fid,'%12.6f %12.6f\n',[S.xloc(iloc) S.yloc(iloc)]);
end
%
% frequencies
%
fprintf(fid,'%s\n',frtype);
nfreq = length(S.freq);
fprintf(fid,'%6i\n',nfreq);
for ifr=1:nfreq
  fprintf(fid,'%10.4f\n',S.freq(ifr));  
end
%
% directions
%
fprintf(fid,'%s\n',dirtype);
ndirs = length(S.dirs);
fprintf(fid,'%6i\n',ndirs);
for idir=1:ndirs
  fprintf(fid,'%10.4f\n',S.dirs(idir));  
end
%
% general information, not yet from struct
%
fprintf(fid,'%s\n','QUANT');
fprintf(fid,'%8i\n',nquant);   
%
for iquant=1:nquant
  fprintf(fid,'%s\n',quant{iquant});
  fprintf(fid,'%s\n',unit{iquant});
  fprintf(fid,'%8i\n',exc(iquant));
end
%
% loop over times and loop over output locations
%
if ktime==1
  wb=waitbar(0,'Writing spectra for all times');
end  
%
for jtime=1:ntime
  if ktime==1
    ctime = [datestr(S.t(jtime),'yyyymmdd.HHMMSS')  '                date and time'];
    fprintf(fid,'%s\n',ctime);
    waitbar(jtime/ntime,wb);
  end
  if ktime==0
    wb=waitbar(0,'Writing spectra for all locations');
  end
%  
  for iloc=1:nloc
    if ktime==0
      waitbar(iloc/nloc,wb);  
      fact   = S.factor(iloc);
      spec2d = S.spec2d(:,:,iloc);
    else
      fact   = S.factor(jtime,iloc);
      spec2d = squeeze(S.spec2d(jtime,:,:,iloc));   
    end      
%          
%     cloc = ['LOCATION ' num2str(iloc,'%5i')];  
%     fprintf(fid,'%s\n',cloc);
    if fact==0
      fprintf(fid,'%s\n','ZERO');
    else
      fprintf(fid,'%s\n','FACTOR');
      fprintf(fid,'%12.8e\n',fact);
%
      for ifreq=1:nfreq
        data = round(spec2d(ifreq,:)/fact); 
        eval(['fprintf(fid,'  '''' format  '''' ',data);'])
        fprintf(fid,'%s\n',' ');
      end    
    end  
  end
end
%
close(wb)
fclose(fid);

